@@ -371,8 +371,15 @@ class TPsimplex:
             self.__find_leaving_indx()
             if self.__set_enter_and_leave_val()==False:
                 return
+            if self.itr>=100:
+                self.msg="\nCannot find solution"
+                self.error=True
+                return
         print('\n\nPHASE-2\n')
-        self.__process_simplex_phase_2()
+        if not self.error:
+            self.__process_simplex_phase_2()
+        else:
+            return
 
 
     def __check_for_optimal_table(self,type='1_phase')->bool:
@@ -444,8 +451,9 @@ class TPsimplex:
             b = self.main_matrix[i][ln]
             x = self.main_matrix[i][self.entering_indx]
             if v in self.artificial_var:
-                if (float(b/x)==min):
-                    self.leaving_indx=i
+                if x>0:
+                    if (float(b/x)==min):
+                        self.leaving_indx=i
 
 
     def __find_leaving_indx(self, type='1_phase'):
@@ -458,6 +466,10 @@ class TPsimplex:
             min = 10000
             l=len(self.optimize_final)-1
             for k in self.main_matrix:
+                if self.entering_indx==None:
+                    self.error=True
+                    self.msg="\nNo Solution Exist!"
+                    return
                 x.append(k[self.entering_indx])
                 b.append(k[l])
 
@@ -476,6 +488,10 @@ class TPsimplex:
 
             l = len(self.main_matrix[0])-1
             for k in self.main_matrix:
+                if self.entering_indx == None:
+                    self.error = True
+                    self.msg = "\nNo Solution Exist!"
+                    return
                 x.append(k[self.entering_indx])
                 b.append(k[l])
 
@@ -493,6 +509,10 @@ class TPsimplex:
 
             l = len(self.main_matrix[0]) - 1
             for k in self.main_matrix:
+                if self.entering_indx==None:
+                    self.error=True
+                    self.msg="\nNo Solution Exist!"
+                    return
                 x.append(k[self.entering_indx])
                 b.append(k[l])
 
@@ -517,6 +537,10 @@ class TPsimplex:
             self.msg="\nUnbounded solution found!"
             return False
 
+        if (self.entering_indx == None):
+            self.error = True
+            self.msg = "\nUnknown error occured!"
+            return False
 
         enter=self.variable[self.entering_indx+1]
         leave=self.basic_var[self.leaving_indx]
@@ -625,6 +649,10 @@ class TPsimplex:
             self.__find_leaving_indx(type=self.optimize_type)
             if self.__set_enter_and_leave_val()==False:
                 return
+            if self.itr>100:
+                self.msg="\nNo solution Found"
+                self.error=True
+                return
 
 
     def Optimal_Solution(self):
@@ -650,6 +678,6 @@ class TPsimplex:
 
                 return np.asarray(final_solution)
             else:
-                return "No Fisible solution found!!"
+                return "\nNo Fisible solution found!!"
         else:
             return self.msg
\ No newline at end of file
